==> haskell-optparse-applicative-0.13.2.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.13.2.0
id: optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
key: optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
license: BSD3
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: paolo@capriotti.io
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System
author: Paolo Capriotti, Huw Campbell
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Pretty Options.Applicative.Help.Chunk
    Options.Applicative.Help.Core Options.Applicative.Help.Types
    Options.Applicative.Types Options.Applicative.Internal
abi: b588fd2553db28d2222b7ec420042105
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/optparse-applicative-0.13.2.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/optparse-applicative-0.13.2.0
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/optparse-applicative-0.13.2.0
hs-libraries: HSoptparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
depends:
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 base-4.9.1.0
    process-1.4.3.0 transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-applicative-0.13.2.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.13.2.0
id: optparse-applicative-0.13.2.0-7H9CfHC8T9lCr98xVjzxwK
key: optparse-applicative-0.13.2.0-7H9CfHC8T9lCr98xVjzxwK
license: BSD3
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: paolo@capriotti.io
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System
author: Paolo Capriotti, Huw Campbell
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Pretty Options.Applicative.Help.Chunk
    Options.Applicative.Help.Core Options.Applicative.Help.Types
    Options.Applicative.Types Options.Applicative.Internal
abi: 3b8b7d5169709b11451f6753915cfb03
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/optparse-applicative-0.13.2.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/optparse-applicative-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/optparse-applicative-0.13.2.0
hs-libraries: HSoptparse-applicative-0.13.2.0-7H9CfHC8T9lCr98xVjzxwK
depends:
    ansi-wl-pprint-0.6.8-442hsaqSoAVL7JUQ0ogC39 base-4.9.1.0
    process-1.4.3.0 transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
